#
# spec file for package fail2ban
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           fail2ban
License:        GPLv2+
Group:          Productivity/Networking/Security
Requires:       python >= 2.5, logrotate
%if 0%{?suse_version}
Requires:	cron
%else
Requires:	vixie-cron
%endif
BuildRequires:  python-devel
%if 0%{?suse_version}
PreReq:         %fillup_prereq
%endif
AutoReqProv:    on
Version:        0.9.7
Release:        3.1
Url:            http://www.fail2ban.org/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        Bans IP addresses that make too many authentication failures
Source0:        %{name}-%{version}.tar.bz2
Source1:        %{name}.init
Source2:        %{name}.sysconfig

%ifarch x86_64
%if 0%{?rhel} || 0%{?centos_version} == 5
%define py_sitedir %{_prefix}/lib/python%{py_ver}/site-packages
%endif
%endif

%description
Fail2ban scans log files like /var/log/messages and bans IP addresses
that makes too many password failures. It updates firewall rules to
reject the IP address, can send e-mails, or set host.deny entries.
These rules can be defined by the user. Fail2Ban can read multiple log
files such as sshd or Apache web server ones.



Authors:
--------
    Cyril Jaquier <cyril.jaquier@fail2ban.org>

%prep
%setup
perl -pi -e 's;/usr/local/;/usr/;g' files/suse-initd

%build
export CFLAGS="$RPM_OPT_FLAGS"
python setup.py build
gzip man/*.1

%install
python setup.py install \
	--root=$RPM_BUILD_ROOT \
	--prefix=%{_prefix}
install -d -m755 $RPM_BUILD_ROOT/%{_mandir}/man1
for i in fail2ban-client fail2ban-regex fail2ban-server; do
	install -m644 man/${i}.1.gz $RPM_BUILD_ROOT/%{_mandir}/man1
done
install -d -m755 $RPM_BUILD_ROOT/%{_sysconfdir}/init.d
install -d -m755 $RPM_BUILD_ROOT/usr/sbin
%if 0%{?suse_version}
install -m755 %{SOURCE1} $RPM_BUILD_ROOT/%{_sysconfdir}/init.d/%{name}
%else
install -m755 files/redhat-initd $RPM_BUILD_ROOT/%{_sysconfdir}/init.d/%{name}
%endif
ln -sf /etc/init.d/%{name} ${RPM_BUILD_ROOT}/usr/sbin/rc%{name}
%if 0%{?suse_version}
install -d -m755 $RPM_BUILD_ROOT/var/adm/fillup-templates
install -m 644 %{SOURCE2} $RPM_BUILD_ROOT/var/adm/fillup-templates/sysconfig.%{name}
%else
install -D -m644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/%{name}
%endif
rm -rf %{buildroot}%{_datadir}/doc/fail2ban/DEVELOP
rm -rf %{buildroot}%{_datadir}/doc/fail2ban/README.md
rm -rf %{buildroot}%{_datadir}/doc/fail2ban/run-rootless.txt
rm -rf %{buildroot}%{_datadir}/doc/fail2ban/FILTERS
rm -rf %{buildroot}%{_datadir}/doc/fail2ban/README.Solaris
rm -rf %{buildroot}%{py_sitedir}/fail2ban-%{version}-py%{py_ver}.egg-info

%post
%if 0%{?suse_version}
%{fillup_only}
%endif

%preun
%if 0%{?suse_version}
%stop_on_removal fail2ban
%endif
%postun
%if 0%{?suse_version}
%restart_on_update fail2ban
%insserv_cleanup
%endif

%clean
# [ "$RPM_BUILD_ROOT" != "" ] && [ -d $RPM_BUILD_ROOT ] && rm -rf $RPM_BUILD_ROOT;

%files
%defattr(-, root, root)
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/action.d
%dir %{_sysconfdir}/%{name}/filter.d
%dir %{_sysconfdir}/%{name}/filter.d/ignorecommands
%config(noreplace) %{_sysconfdir}/%{name}/*.conf
%config %{_sysconfdir}/%{name}/action.d/*.conf
%config %{_sysconfdir}/%{name}/filter.d/*.conf
%{_sysconfdir}/%{name}/action.d/*.py
%{_sysconfdir}/%{name}/filter.d/ignorecommands/apache-fakegooglebot
%{_sysconfdir}/init.d/%{name}
/usr/bin/%{name}*
/usr/sbin/rc%{name}
%dir %{py_sitedir}/fail2ban
%dir %{py_sitedir}/fail2ban/client
%dir %{py_sitedir}/fail2ban/server
%dir %{py_sitedir}/fail2ban/tests
%dir %{py_sitedir}/fail2ban/tests/config
%dir %{py_sitedir}/fail2ban/tests/config/action.d
%dir %{py_sitedir}/fail2ban/tests/config/filter.d
%dir %{py_sitedir}/fail2ban/tests/files
%dir %{py_sitedir}/fail2ban/tests/files/config
%dir %{py_sitedir}/fail2ban/tests/files/config/apache-auth
%dir %{py_sitedir}/fail2ban/tests/files/filter.d
%dir %{py_sitedir}/fail2ban/tests/files/logs
%dir %{py_sitedir}/fail2ban/tests/action_d
%dir %{py_sitedir}/fail2ban/tests/files/action.d
%dir %{py_sitedir}/fail2ban/tests/files/config/apache-auth/basic
%dir %{py_sitedir}/fail2ban/tests/files/config/apache-auth/basic/authz_owner
%dir %{py_sitedir}/fail2ban/tests/files/config/apache-auth/basic/file
%dir %{py_sitedir}/fail2ban/tests/files/config/apache-auth/digest
%dir %{py_sitedir}/fail2ban/tests/files/config/apache-auth/digest_anon
%dir %{py_sitedir}/fail2ban/tests/files/config/apache-auth/digest_time
%dir %{py_sitedir}/fail2ban/tests/files/config/apache-auth/digest_wrongrelm
%dir %{py_sitedir}/fail2ban/tests/files/config/apache-auth/noentry
%dir %{py_sitedir}/fail2ban/tests/files/logs/bsd
%dir %{py_sitedir}/fail2ban/tests/files/logs/apache-pass
%dir %{py_sitedir}/fail2ban/tests/files/logs/froxlor-auth
%{py_sitedir}/fail2ban/__init__.py*
%{py_sitedir}/fail2ban/client/__init__.py*
%{py_sitedir}/fail2ban/client/actionreader.py*
%{py_sitedir}/fail2ban/client/beautifier.py*
%{py_sitedir}/fail2ban/client/configparserinc.py*
%{py_sitedir}/fail2ban/client/configreader.py*
%{py_sitedir}/fail2ban/client/configurator.py*
%{py_sitedir}/fail2ban/client/csocket.py*
%{py_sitedir}/fail2ban/client/fail2banreader.py*
%{py_sitedir}/fail2ban/client/filterreader.py*
%{py_sitedir}/fail2ban/client/jailreader.py*
%{py_sitedir}/fail2ban/client/jailsreader.py*
%{py_sitedir}/fail2ban/exceptions.py*
%{py_sitedir}/fail2ban/helpers.py*
%{py_sitedir}/fail2ban/protocol.py*
%{py_sitedir}/fail2ban/server/__init__.py*
%{py_sitedir}/fail2ban/server/action.py*
%{py_sitedir}/fail2ban/server/actions.py*
%{py_sitedir}/fail2ban/server/asyncserver.py*
%{py_sitedir}/fail2ban/server/banmanager.py*
%{py_sitedir}/fail2ban/server/database.py*
%{py_sitedir}/fail2ban/server/datedetector.py*
%{py_sitedir}/fail2ban/server/datetemplate.py*
%{py_sitedir}/fail2ban/server/faildata.py*
%{py_sitedir}/fail2ban/server/failmanager.py*
%{py_sitedir}/fail2ban/server/failregex.py*
%{py_sitedir}/fail2ban/server/filter.py*
%{py_sitedir}/fail2ban/server/filtergamin.py*
%{py_sitedir}/fail2ban/server/filterpoll.py*
%{py_sitedir}/fail2ban/server/filterpyinotify.py*
%{py_sitedir}/fail2ban/server/filtersystemd.py*
%{py_sitedir}/fail2ban/server/jail.py*
%{py_sitedir}/fail2ban/server/jails.py*
%{py_sitedir}/fail2ban/server/jailthread.py*
%{py_sitedir}/fail2ban/server/mytime.py*
%{py_sitedir}/fail2ban/server/server.py*
%{py_sitedir}/fail2ban/server/strptime.py*
%{py_sitedir}/fail2ban/server/ticket.py*
%{py_sitedir}/fail2ban/server/transmitter.py*
%{py_sitedir}/fail2ban/tests/__init__.py*
%{py_sitedir}/fail2ban/tests/action_d/__init__.py*
%{py_sitedir}/fail2ban/tests/action_d/test_badips.py*
%{py_sitedir}/fail2ban/tests/action_d/test_smtp.py*
%{py_sitedir}/fail2ban/tests/actionstestcase.py*
%{py_sitedir}/fail2ban/tests/actiontestcase.py*
%{py_sitedir}/fail2ban/tests/banmanagertestcase.py*
%{py_sitedir}/fail2ban/tests/clientreadertestcase.py*
%{py_sitedir}/fail2ban/tests/config/action.d/brokenaction.conf
%{py_sitedir}/fail2ban/tests/config/fail2ban.conf
%{py_sitedir}/fail2ban/tests/config/filter.d/simple.conf
%{py_sitedir}/fail2ban/tests/config/filter.d/test.conf
%{py_sitedir}/fail2ban/tests/config/filter.d/test.local
%{py_sitedir}/fail2ban/tests/config/jail.conf
%{py_sitedir}/fail2ban/tests/databasetestcase.py*
%{py_sitedir}/fail2ban/tests/datedetectortestcase.py*
%{py_sitedir}/fail2ban/tests/dummyjail.py*
%{py_sitedir}/fail2ban/tests/failmanagertestcase.py*
%{py_sitedir}/fail2ban/tests/files/action.d/action.py*
%{py_sitedir}/fail2ban/tests/files/action.d/action_checkainfo.py*
%{py_sitedir}/fail2ban/tests/files/action.d/action_errors.py*
%{py_sitedir}/fail2ban/tests/files/action.d/action_modifyainfo.py*
%{py_sitedir}/fail2ban/tests/files/action.d/action_noAction.py*
%{py_sitedir}/fail2ban/tests/files/action.d/action_nomethod.py*
%{py_sitedir}/fail2ban/tests/files/config/apache-auth/README
%{py_sitedir}/fail2ban/tests/files/config/apache-auth/basic/authz_owner/.htaccess
%{py_sitedir}/fail2ban/tests/files/config/apache-auth/basic/authz_owner/.htpasswd
%{py_sitedir}/fail2ban/tests/files/config/apache-auth/basic/authz_owner/cant_get_me.html
%{py_sitedir}/fail2ban/tests/files/config/apache-auth/basic/file/.htaccess
%{py_sitedir}/fail2ban/tests/files/config/apache-auth/basic/file/.htpasswd
%{py_sitedir}/fail2ban/tests/files/config/apache-auth/digest.py*
%{py_sitedir}/fail2ban/tests/files/config/apache-auth/digest/.htaccess
%{py_sitedir}/fail2ban/tests/files/config/apache-auth/digest/.htpasswd
%{py_sitedir}/fail2ban/tests/files/config/apache-auth/digest_anon/.htaccess
%{py_sitedir}/fail2ban/tests/files/config/apache-auth/digest_anon/.htpasswd
%{py_sitedir}/fail2ban/tests/files/config/apache-auth/digest_time/.htaccess
%{py_sitedir}/fail2ban/tests/files/config/apache-auth/digest_time/.htpasswd
%{py_sitedir}/fail2ban/tests/files/config/apache-auth/digest_wrongrelm/.htaccess
%{py_sitedir}/fail2ban/tests/files/config/apache-auth/digest_wrongrelm/.htpasswd
%{py_sitedir}/fail2ban/tests/files/config/apache-auth/noentry/.htaccess
%{py_sitedir}/fail2ban/tests/files/database_v1.db
%{py_sitedir}/fail2ban/tests/files/filter.d/substition.conf
%{py_sitedir}/fail2ban/tests/files/filter.d/testcase-common.conf
%{py_sitedir}/fail2ban/tests/files/filter.d/testcase01.conf
%{py_sitedir}/fail2ban/tests/files/ignorecommand.py*
%{py_sitedir}/fail2ban/tests/files/logs/3proxy
%{py_sitedir}/fail2ban/tests/files/logs/apache-auth
%{py_sitedir}/fail2ban/tests/files/logs/apache-badbots
%{py_sitedir}/fail2ban/tests/files/logs/apache-botsearch
%{py_sitedir}/fail2ban/tests/files/logs/apache-fakegooglebot
%{py_sitedir}/fail2ban/tests/files/logs/apache-modsecurity
%{py_sitedir}/fail2ban/tests/files/logs/apache-nohome
%{py_sitedir}/fail2ban/tests/files/logs/apache-noscript
%{py_sitedir}/fail2ban/tests/files/logs/apache-overflows
%{py_sitedir}/fail2ban/tests/files/logs/apache-shellshock
%{py_sitedir}/fail2ban/tests/files/logs/assp
%{py_sitedir}/fail2ban/tests/files/logs/asterisk
%{py_sitedir}/fail2ban/tests/files/logs/bsd/syslog-plain.txt
%{py_sitedir}/fail2ban/tests/files/logs/bsd/syslog-v.txt
%{py_sitedir}/fail2ban/tests/files/logs/bsd/syslog-vv.txt
%{py_sitedir}/fail2ban/tests/files/logs/counter-strike
%{py_sitedir}/fail2ban/tests/files/logs/courier-auth
%{py_sitedir}/fail2ban/tests/files/logs/courier-smtp
%{py_sitedir}/fail2ban/tests/files/logs/cyrus-imap
%{py_sitedir}/fail2ban/tests/files/logs/directadmin
%{py_sitedir}/fail2ban/tests/files/logs/dovecot
%{py_sitedir}/fail2ban/tests/files/logs/dropbear
%{py_sitedir}/fail2ban/tests/files/logs/drupal-auth
%{py_sitedir}/fail2ban/tests/files/logs/ejabberd-auth
%{py_sitedir}/fail2ban/tests/files/logs/exim
%{py_sitedir}/fail2ban/tests/files/logs/exim-spam
%{py_sitedir}/fail2ban/tests/files/logs/freeswitch
%{py_sitedir}/fail2ban/tests/files/logs/groupoffice
%{py_sitedir}/fail2ban/tests/files/logs/gssftpd
%{py_sitedir}/fail2ban/tests/files/logs/guacamole
%{py_sitedir}/fail2ban/tests/files/logs/horde
%{py_sitedir}/fail2ban/tests/files/logs/kerio
%{py_sitedir}/fail2ban/tests/files/logs/lighttpd-auth
%{py_sitedir}/fail2ban/tests/files/logs/monit
%{py_sitedir}/fail2ban/tests/files/logs/mysqld-auth
%{py_sitedir}/fail2ban/tests/files/logs/nagios
%{py_sitedir}/fail2ban/tests/files/logs/named-refused
%{py_sitedir}/fail2ban/tests/files/logs/nginx-botsearch
%{py_sitedir}/fail2ban/tests/files/logs/nginx-http-auth
%{py_sitedir}/fail2ban/tests/files/logs/nsd
%{py_sitedir}/fail2ban/tests/files/logs/openwebmail
%{py_sitedir}/fail2ban/tests/files/logs/oracleims
%{py_sitedir}/fail2ban/tests/files/logs/pam-generic
%{py_sitedir}/fail2ban/tests/files/logs/perdition
%{py_sitedir}/fail2ban/tests/files/logs/php-url-fopen
%{py_sitedir}/fail2ban/tests/files/logs/portsentry
%{py_sitedir}/fail2ban/tests/files/logs/postfix
%{py_sitedir}/fail2ban/tests/files/logs/postfix-rbl
%{py_sitedir}/fail2ban/tests/files/logs/postfix-sasl
%{py_sitedir}/fail2ban/tests/files/logs/proftpd
%{py_sitedir}/fail2ban/tests/files/logs/pure-ftpd
%{py_sitedir}/fail2ban/tests/files/logs/qmail
%{py_sitedir}/fail2ban/tests/files/logs/recidive
%{py_sitedir}/fail2ban/tests/files/logs/roundcube-auth
%{py_sitedir}/fail2ban/tests/files/logs/selinux-ssh
%{py_sitedir}/fail2ban/tests/files/logs/sendmail-auth
%{py_sitedir}/fail2ban/tests/files/logs/sendmail-reject
%{py_sitedir}/fail2ban/tests/files/logs/sieve
%{py_sitedir}/fail2ban/tests/files/logs/sogo-auth
%{py_sitedir}/fail2ban/tests/files/logs/solid-pop3d
%{py_sitedir}/fail2ban/tests/files/logs/squid
%{py_sitedir}/fail2ban/tests/files/logs/squirrelmail
%{py_sitedir}/fail2ban/tests/files/logs/sshd
%{py_sitedir}/fail2ban/tests/files/logs/sshd-ddos
%{py_sitedir}/fail2ban/tests/files/logs/stunnel
%{py_sitedir}/fail2ban/tests/files/logs/suhosin
%{py_sitedir}/fail2ban/tests/files/logs/tine20
%{py_sitedir}/fail2ban/tests/files/logs/uwimap-auth
%{py_sitedir}/fail2ban/tests/files/logs/vsftpd
%{py_sitedir}/fail2ban/tests/files/logs/webmin-auth
%{py_sitedir}/fail2ban/tests/files/logs/wuftpd
%{py_sitedir}/fail2ban/tests/files/logs/xinetd-fail
%{py_sitedir}/fail2ban/tests/files/testcase-journal.log
%{py_sitedir}/fail2ban/tests/files/testcase-multiline.log
%{py_sitedir}/fail2ban/tests/files/testcase-usedns.log
%{py_sitedir}/fail2ban/tests/files/testcase01.log
%{py_sitedir}/fail2ban/tests/files/testcase02.log
%{py_sitedir}/fail2ban/tests/files/testcase03.log
%{py_sitedir}/fail2ban/tests/files/testcase04.log
%{py_sitedir}/fail2ban/tests/filtertestcase.py*
%{py_sitedir}/fail2ban/tests/misctestcase.py*
%{py_sitedir}/fail2ban/tests/samplestestcase.py*
%{py_sitedir}/fail2ban/tests/servertestcase.py*
%{py_sitedir}/fail2ban/tests/sockettestcase.py*
%{py_sitedir}/fail2ban/tests/utils.py*
%{py_sitedir}/fail2ban/version.py*
%{py_sitedir}/fail2ban/client/fail2banregex.py*
%{py_sitedir}/fail2ban/setup.py*
%{py_sitedir}/fail2ban/tests/config/filter.d/zzz-generic-example.conf
%{py_sitedir}/fail2ban/tests/fail2banregextestcase.py*
%{py_sitedir}/fail2ban/tests/files/logs/domino-smtp
%{py_sitedir}/fail2ban/tests/files/logs/haproxy-http-auth
%{py_sitedir}/fail2ban/tests/files/logs/mongodb-auth
%{py_sitedir}/fail2ban/tests/files/logs/murmur
%{py_sitedir}/fail2ban/tests/files/logs/nginx-limit-req
%{py_sitedir}/fail2ban/tests/files/logs/openhab
%{py_sitedir}/fail2ban/tests/files/logs/screensharingd
%{py_sitedir}/fail2ban/tests/files/logs/slapd
%{py_sitedir}/fail2ban/tests/files/logs/sshd-aggressive
%{py_sitedir}/fail2ban/tests/files/logs/zzz-generic-example
%{py_sitedir}/fail2ban/tests/files/testcase-wrong-char.log


%if 0%{?suse_version}
/var/adm/fillup-templates/sysconfig.%{name}
%else
%{_sysconfdir}/sysconfig/%{name}
%endif
%doc %{_mandir}/man1/*
%doc COPYING ChangeLog TODO files/cacti
%doc DEVELOP README.md doc/run-rootless.txt
%doc FILTERS

%changelog
* Wed May 17 2017 cs@linux-administrator.com
- update to release 0.9.7
* Tue Jan 19 2016 cs@linux-administrator.com
- update to release 0.9.3
* Sun Sep  7 2014 cs@linux-administrator.com
- update to release 0.8.14
* Sat Nov 16 2013 cs@linux-administrator.com
- update to release 0.8.11
* Sat Jul  6 2013 cs@linux-administrator.com
- update to security release 0.8.10
* Sun Feb 10 2013 cs@linux-administrator.com
- cleanup stale socket on startup
* Thu Dec 13 2012 cs@linux-administrator.com
- update to release 0.8.8
* Wed May  5 2010 lchiquitto@novell.com
- Create /var/run/fail2ban during startup to support systems that
  mount /var/run as tmpfs
- Build package as noarch
- Spec file cleanup: fix a couple of rpmlint warnings
- Init script: look for fail2ban-server when checking if the
  daemon is running
* Thu Nov 26 2009 lchiquitto@suse.de
- Update to version 0.8.4. Important changes:
  * New "Ban IP" command
  * New filters: lighttpd-fastcgi php-url-fopen cyrus-imap sieve
  * Fixed the 'unexpected communication error' problem
  * Remove socket file on startup if fail2ban crashed (bnc#537239)
* Wed Feb  4 2009 kssingvo@suse.de
- Initial version: 0.8.3
